@@ -11,7 +11,6 @@ use kube::api;
 use kube::config;
 use kube::{Resource, ResourceExt};
 use serde::{de, ser};
-use serde_yaml as yaml;
 
 use super::*;
 
@@ -119,15 +118,8 @@ impl fmt::Debug for Kubectl {
     }
 }
 
-fn kubeconfig(text: &str) -> Result<config::Kubeconfig, config::KubeconfigError> {
-    let value: yaml::Value = yaml::from_str(text).map_err(config::KubeconfigError::Parse)?;
-    let kubeconfig = yaml::from_value(value).map_err(config::KubeconfigError::InvalidStructure)?;
-
-    Ok(kubeconfig)
-}
-
 async fn load_config_from_text(text: &str) -> Result<config::Config, config::KubeconfigError> {
-    let kubeconfig = kubeconfig(text)?;
+    let kubeconfig = config::Kubeconfig::from_yaml(text)?;
     let options = kube::config::KubeConfigOptions::default();
     config::Config::from_custom_kubeconfig(kubeconfig, &options).await
 }
