@@ -27,3 +27,17 @@ pub use k8s_openapi::apimachinery::pkg::apis::meta::v1 as metav1;
 pub use kubectl::Kubectl;
 
 mod kubectl;
+
+pub fn typed_ref(
+    object: Option<&corev1::ObjectReference>,
+) -> Option<corev1::TypedLocalObjectReference> {
+    let object = object?;
+    let kind = object.kind.as_ref()?.clone();
+    let name = object.name.as_ref()?.clone();
+    let typed = corev1::TypedLocalObjectReference {
+        kind,
+        name,
+        ..corev1::TypedLocalObjectReference::default()
+    };
+    Some(typed)
+}
